@@ -102,11 +102,13 @@ _ALL_TIMEZONES = [
   ("-0400", "Canada/Atlantic", '(GMT-0400) Atlantic Time (Canada)'),
   ("-0400", "Etc/GMT-4", '(GMT-0400) La Paz'),
   ("-0400", "America/Santiago", '(GMT-0400) Santiago'),
+  ("-0400", "America/Cuiaba", '(GMT-0400) Mato Grosso'),
   ("-0330", "Canada/Newfoundland", '(GMT-0330) Newfoundland'),
   ("-0300", "Brazil/East", '(GMT-0300) Brasilia'),
   ("-0300", "America/Argentina/Buenos_Aires", '(GMT-0300) Buenos Aires'),
   ("-0300", "America/Guyana", '(GMT-0300) Georgetown'),
   ("-0300", "America/Godthab", '(GMT-0300) Greenland'),
+  ("-0300", "America/Fortaleza", '(GMT-0300) NE Brazil'),
   ("-0100", "Atlantic/Azores", '(GMT-0100) Azores'),
   ("-0100", "Atlantic/Cape_Verde", '(GMT-0100) Cape Verde Is. '),
   ("+0000", "Africa/Casablanca", '(GMT+0000) Casablanca'),
